"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .partitionlimits import PartitionLimits, PartitionLimitsTypedDict
from .partitionstats import PartitionStats, PartitionStatsTypedDict
from datetime import datetime
from pydantic import model_serializer
from ragie.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from typing import Any, Dict, List, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


PartitionDetailMetadataSchemaTypedDict = TypeAliasType(
    "PartitionDetailMetadataSchemaTypedDict",
    Union[str, int, bool, List[str], Dict[str, Any]],
)


PartitionDetailMetadataSchema = TypeAliasType(
    "PartitionDetailMetadataSchema", Union[str, int, bool, List[str], Dict[str, Any]]
)


class PartitionDetailTypedDict(TypedDict):
    name: str
    is_default: bool
    description: Nullable[str]
    context_aware: bool
    metadata_schema: Nullable[Dict[str, PartitionDetailMetadataSchemaTypedDict]]
    limits: PartitionLimitsTypedDict
    stats: PartitionStatsTypedDict
    limit_exceeded_at: NotRequired[Nullable[datetime]]
    r"""Timestamp when the partition exceeded its limits, if applicable."""


class PartitionDetail(BaseModel):
    name: str

    is_default: bool

    description: Nullable[str]

    context_aware: bool

    metadata_schema: Nullable[Dict[str, PartitionDetailMetadataSchema]]

    limits: PartitionLimits

    stats: PartitionStats

    limit_exceeded_at: OptionalNullable[datetime] = UNSET
    r"""Timestamp when the partition exceeded its limits, if applicable."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["limit_exceeded_at"]
        nullable_fields = ["limit_exceeded_at", "description", "metadata_schema"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
