"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from pydantic.functional_validators import AfterValidator
from ragie.types import BaseModel
from ragie.utils import validate_const
from typing import Literal, Optional
from typing_extensions import Annotated, TypedDict


class CodeInterpreterOutputLogsTypedDict(TypedDict):
    logs: str
    r"""The logs output from the code interpreter."""
    type: Literal["logs"]


class CodeInterpreterOutputLogs(BaseModel):
    logs: str
    r"""The logs output from the code interpreter."""

    TYPE: Annotated[
        Annotated[Optional[Literal["logs"]], AfterValidator(validate_const("logs"))],
        pydantic.Field(alias="type"),
    ] = "logs"
