"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing import Any, Dict
from typing_extensions import TypedDict


class FileSearchResultTypedDict(TypedDict):
    file_id: str
    r"""The unique ID of the document."""
    filename: str
    r"""The name of the document."""
    score: float
    r"""The relevance score of the chunk - a value between 0 and 1."""
    text: str
    r"""The text content of the chunk."""
    attributes: Dict[str, Any]
    r"""The attributes of the chunk."""


class FileSearchResult(BaseModel):
    file_id: str
    r"""The unique ID of the document."""

    filename: str
    r"""The name of the document."""

    score: float
    r"""The relevance score of the chunk - a value between 0 and 1."""

    text: str
    r"""The text content of the chunk."""

    attributes: Dict[str, Any]
    r"""The attributes of the chunk."""
