"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class SearchEffort(str, Enum):
    LOW = "low"
    MEDIUM = "medium"
    HIGH = "high"
