"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from pydantic.functional_validators import AfterValidator
from ragie.types import BaseModel
from ragie.utils import validate_const
from typing import Literal, Optional
from typing_extensions import Annotated, TypedDict


class ReasoningSummaryTypedDict(TypedDict):
    summary: str
    r"""The summary of the reasoning."""
    type: Literal["summary"]


class ReasoningSummary(BaseModel):
    summary: str
    r"""The summary of the reasoning."""

    TYPE: Annotated[
        Annotated[
            Optional[Literal["summary"]], AfterValidator(validate_const("summary"))
        ],
        pydantic.Field(alias="type"),
    ] = "summary"
