"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .pagination import Pagination, PaginationTypedDict
from .webhookendpoint import WebhookEndpoint, WebhookEndpointTypedDict
from ragie.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class WebhookEndpointListTypedDict(TypedDict):
    pagination: PaginationTypedDict
    webhook_endpoints: List[WebhookEndpointTypedDict]


class WebhookEndpointList(BaseModel):
    pagination: Pagination

    webhook_endpoints: List[WebhookEndpoint]
