"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .ragieevidence import RagieEvidence, RagieEvidenceTypedDict
from .searcheffort import SearchEffort
from ragie.types import BaseModel
from typing import Any, Dict, List
from typing_extensions import TypedDict


class QueryDetailsTypedDict(TypedDict):
    query: str
    search_effort: SearchEffort
    metadata_filter: Dict[str, Any]
    search_results: List[RagieEvidenceTypedDict]


class QueryDetails(BaseModel):
    query: str

    search_effort: SearchEffort

    metadata_filter: Dict[str, Any]

    search_results: List[RagieEvidence]
