"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .updatewebhookendpointpayload import (
    UpdateWebhookEndpointPayload,
    UpdateWebhookEndpointPayloadTypedDict,
)
from ragie.types import BaseModel
from ragie.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateWebhookEndpointRequestTypedDict(TypedDict):
    endpoint_id: str
    update_webhook_endpoint_payload: UpdateWebhookEndpointPayloadTypedDict


class UpdateWebhookEndpointRequest(BaseModel):
    endpoint_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    update_webhook_endpoint_payload: Annotated[
        UpdateWebhookEndpointPayload,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
